Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1481)

Unified Diff: remoting/client/ios/bridge/host_preferences.h

Issue 2628403002: Migrating host preferences, runtime, and gestures to chromium from internal. (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/ios/bridge/host_preferences.h
diff --git a/remoting/client/ios/host_preferences.h b/remoting/client/ios/bridge/host_preferences.h
similarity index 74%
copy from remoting/client/ios/host_preferences.h
copy to remoting/client/ios/bridge/host_preferences.h
index 6fb19a0a1276bd8d7299e935dd18a9506854e329..5bc8248a90e6ee9c75c7f7c081abe9f7fd117f4b 100644
--- a/remoting/client/ios/host_preferences.h
+++ b/remoting/client/ios/bridge/host_preferences.h
@@ -8,7 +8,7 @@
#import <CoreData/CoreData.h>
// A HostPreferences contains details to negotiate and maintain a connection
-// to a remote Chromoting host. This is an entity in a backing store.
+// to a remote Chromoting host. This is an entity in a backing store.
@interface HostPreferences : NSObject<NSCoding>
@@ -17,12 +17,10 @@
@property(nonatomic, copy) NSString* pairId;
@property(nonatomic, copy) NSString* pairSecret;
-// Commit this record using the SSOKeychain
-// for SSOSigninManager's current identity.
-- (void)saveToSSOKeychain;
+// Commit the current idendity to the keychain.
nicholss 2017/01/13 19:20:34 More language changing to remove SSO.
+- (void)saveToKeychain;
-// Load a record from the SSOKeychain
-// for SSOSigninManager's current identity.
+// Load a record from the Keychain current identity.
// If a record does not exist, return a new record with a blank secret.
+ (HostPreferences*)hostForId:(NSString*)hostId;

Powered by Google App Engine
This is Rietveld 408576698